-- Created by NuclearTonic
-- If reusing this code, please keep the name of the original author listed
-- in respect for borrowing said authors code.
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Tonic.Utils.Class";
import "Tonic.TonicBars.Bars.BaseBar";
import "Tonic.TonicBars.Bars.Quickslots.QuickslotBar";
import "Tonic.TonicBars.Bars.Extension.ExtensionBar";
import "Tonic.TonicBars.Bars.Inventory.TabbedBar";
import "Tonic.TonicBars.Bars.Inventory.WindowBar";

BarManager = class( Turbine.Object );

function BarManager:Constructor()
	self.working = false;
	RegisteredBars = { };
	
	self:Construct( theSettingsManager:GetBars() );
end

function BarManager:RefreshBars()
	for key, value in pairs (RegisteredBars) do
		value:Refresh();
	end
end

function BarManager:Add( barType, cBarID, cQuickslotID )
	local tonic = nil;
	if ( self.working == false ) then
		self.working = true;
		local settings = theSettingsManager:GetSettings();
		local added = settings.nextBarId;
		if ( cBarID ~= nil and barType ~= EXTENSIONBAR ) then
			added = cBarID;
		end

		if ( barType == QUICKSLOTBAR ) then
			tonic = Tonic.TonicBars.Bars.Quickslots.QuickslotBar( added );
		elseif ( barType == EXTENSIONBAR ) then
			local barSettings = theSettingsManager:GetBarSettings( cBarID );
			added = settings.nextBarId;
			if ( barSettings.barType == QUICKSLOTBAR ) then
				tonic = Tonic.TonicBars.Bars.Extension.ExtensionBar( added );
				RegisteredBars[cBarID]:RegisterBarExtension( tonic, cQuickslotID, added );
			else
				Turbine.Shell.WriteLine( "You can not add an extension to an extension." );
			end
		elseif ( barType == TABBED_INV_BAR ) then
			tonic = Tonic.TonicBars.Bars.Inventory.TabbedBar( added );
		elseif ( barType == WINDOW_INV_BAR ) then
			tonic = Tonic.TonicBars.Bars.Inventory.WindowBar( added );
		end
		if ( tonic ~= nil ) then
			RegisteredBars[added] = tonic;
			if ( added == settings.nextBarId ) then
				theSettingsManager:IncrementNextId();
			end
			local barSettings = theSettingsManager:GetBarSettings( added );
			theSettingsManager:SetBarSettings( added, barSettings );
			self.working = false;
			return added;
		else
			self.working = false;
			return nil;
		end
	else
		Turbine.Shell.WriteLine( "Your actions are occuring too quickly, please slow down." );
		return nil;
	end
end

function BarManager:Remove( barid, removeSettingsWhenNil )
	if ( barid ~= nil and RegisteredBars[barid] ~= nil ) then
		eventManager:UnregisterForEvents( barid );

		RegisteredBars[barid]:SetVisible( false );
		RegisteredBars[barid]:SetParent( nil );
		if ( removeSettingsWhenNil == nil ) then
			RegisteredBars[barid]:ClearQuickslots( true );
		else
			RegisteredBars[barid]:ClearQuickslots();
		end
		if ( RegisteredBars[barid].Remove ~= nil ) then
			RegisteredBars[barid]:Remove()
		end
		RegisteredBars[barid]:SetVisible( false );
		RegisteredBars[barid]:SetBackColor( Turbine.UI.Color( 0, 0, 0, 0) );
		RegisteredBars[barid] = nil;

		Turbine.Shell.WriteLine( "Removing:" .. barid );

		if ( removeSettingsWhenNil == nil ) then
			theSettingsManager:SetBarSettings( barid, nil);
		end
	end
end

function BarManager:Copy( barid, bartype )
	if ( barid ~= nil and self.working == false ) then
		self.working = true;
		theSettingsManager:CopyBars( player:GetName(), self.PARTIAL, barid, true );
		theSettingsManager:ResetAllBars();
	else
		return nil;
	end
end

function BarManager:Reset( barid )
	if ( barid ~= nil and self.working == false ) then
		self.working = true;	
		local barsettings = theSettingsManager:GetBarSettings( barid );
		tempType = barsettings.barType;
		theSettingsManager:SetBarSettings( barid, nil, false );
		barsettings = theSettingsManager:GetBarSettings( barid );
		barsettings.barType = tempType;
		theSettingsManager:SetBarSettings( barid, barsettings );
		self.working = false;
	else
		return nil;
	end
end

function BarManager:Construct( storedBars, second )
	for key, value in pairs (storedBars) do
		if ( value.barType == QUICKSLOTBAR ) then
			tonic = Tonic.TonicBars.Bars.Quickslots.QuickslotBar( tonumber(key) );
			RegisteredBars[tonumber(key)] = tonic;
		end
		if ( value.barType == TABBED_INV_BAR ) then
			tonic = Tonic.TonicBars.Bars.Inventory.TabbedBar( tonumber(key) );
			RegisteredBars[tonumber(key)] = tonic;
		end
		if ( value.barType == WINDOW_INV_BAR ) then
			tonic = Tonic.TonicBars.Bars.Inventory.WindowBar( tonumber(key) );
			RegisteredBars[tonumber(key)] = tonic;
		end
	end

	for key, value in pairs (storedBars) do
		if ( value.barType == EXTENSIONBAR ) then
			tonic = Tonic.TonicBars.Bars.Extension.ExtensionBar( key );
			local attachedbarSettings = theSettingsManager:GetBarSettings( key );
			local thebar = RegisteredBars[attachedbarSettings.connectionBarID];
			if ( thebar ~= nil ) then
				thebar:RegisterBarExtension( tonic, attachedbarSettings.connectionQuickslotID, key );
				RegisteredBars[tonumber(key)] = tonic;
			else
				theSettingsManager:SetBarSettings( key, nil);
				Turbine.Shell.WriteLine( "We found extension bar without a main bar. Deleting. Thank the community for the fix." );
			end
		end
	end
end

function BarManager:GetBars()
	return RegisteredBars;
end

function BarManager:ShowExtensionBarMenu( barid )
	RegisteredBars[ barid ]:ShowBarMenu();
end

function BarManager:UpdateBarExtensions()
	for key, value in pairs (RegisteredBars) do
		local barsettings = theSettingsManager:GetBarSettings( key );
		if ( barsettings.barType == QUICKSLOTBAR and value ~= nil ) then
			RegisteredBars[ key ]:UpdateBarExtensions();
		end
	end
end

function BarManager:Alive( barid )
	if ( RegisteredBars[barid] == nil ) then
		return false;
	else
		return true;
	end
end

function BarManager:LoadQuickslots()
	for key, value in pairs (RegisteredBars) do
		local bSettings = theSettingsManager:GetBarSettings( key );
		if ( bSettings.barType == QUICKSLOTBAR or bSettings.barType == EXTENSIONBAR ) then
			theSettingsManager:LoadQuickslots( bSettings, RegisteredBars[ key ]:GetQuickslotList().quickslots );
		end
	end
end

function BarManager:ExtensionMousedOver()
end

function BarManager:ExtensionMousedLeft()
end